package sorare_utils

import (
	"git.lehouerou.net/laurent/sorare/football"
	"github.com/shopspring/decimal"

	"git.lehouerou.net/laurent/sorarebuddy/model"
)

func NewCreateOrUpdateGamePlayerScoresParamsFromSorare(
	gameId string,
	playerScore football.PlayerScore,
) model.CreateOrUpdateGamePlayerScoresParams {
	s := playerScore.So5Score

	res := model.CreateOrUpdateGamePlayerScoresParams{
		GameID:         gameId,
		PlayerSlug:     s.Player.Slug,
		MinutesPlayed:  int32(s.PlayerGameStats.MinsPlayed),
		GameStarted:    s.PlayerGameStats.GameStarted == 1,
		FormationPlace: int32(s.PlayerGameStats.FormationPlace),
		Live:           s.PlayerGameStats.Live,
		OnGameSheet:    s.PlayerGameStats.OnGameSheet,
		Reviewed:       s.PlayerGameStats.Reviewed,
	}
	score := s.Score
	decisiveScore := s.DecisiveScore.TotalScore
	allAroundScore := decimal.Zero
	tacklefound := false
	for _, stat := range s.AllAroundStats {
		switch stat.Stat {
		case "yellow_card":
			res.YellowCard = int32(stat.StatValue.IntPart())
		case "fouls":
			res.Fouls = int32(stat.StatValue.IntPart())
		case "was_fouled":
			res.Fouled = int32(stat.StatValue.IntPart())
		case "clean_sheet_60":
			res.CleanSheet = int(stat.StatValue.IntPart()) == 1
		case "double_double":
			res.DoubleDouble = int(stat.StatValue.IntPart()) == 1
		case "triple_double":
			res.TripleDouble = int(stat.StatValue.IntPart()) == 1
		case "triple_triple":
			res.TripleTriple = int(stat.StatValue.IntPart()) == 1
		case "error_lead_to_shot":
			res.ErrorLeadToShot = int32(stat.StatValue.IntPart())

		case "saves":
			res.Saves = int32(stat.StatValue.IntPart())
		case "saved_ibox":
			res.SavedShotFromInsideBox = int32(stat.StatValue.IntPart())
		case "good_high_claim":
			res.GoodHighClaim = int32(stat.StatValue.IntPart())
		case "punches":
			res.Punches = int32(stat.StatValue.IntPart())
		case "dive_save":
			res.DivingSave = int32(stat.StatValue.IntPart())
		case "dive_catch":
			res.DivingCatch = int32(stat.StatValue.IntPart())
		case "cross_not_claimed":
			res.CrossNotClaimed = int32(stat.StatValue.IntPart())
		case "six_second_violation":
			res.SixSecondViolation = int32(stat.StatValue.IntPart())
		case "gk_smother":
			res.GoalkeeperSmother = int32(stat.StatValue.IntPart())
		case "accurate_keeper_sweeper":
			res.KeeperSweeper = int32(stat.StatValue.IntPart())

		case "goals_conceded":
			res.GoalsConceded = int32(stat.StatValue.IntPart())
		case "effective_clearance":
			res.EffectiveClearance = int32(stat.StatValue.IntPart())
		case "won_tackle":
			res.WonTackle = int32(stat.StatValue.IntPart())
			tacklefound = true
		case "blocked_cross":
			res.BlockedCross = int32(stat.StatValue.IntPart())
		case "outfielder_block":
			res.Block = int32(stat.StatValue.IntPart())

		case "poss_lost_ctrl":
			res.PossessionLost = int32(stat.StatValue.IntPart())
		case "poss_won":
			res.PossessionWon = int32(stat.StatValue.IntPart())
		case "duel_lost":
			res.DuelLost = int32(stat.StatValue.IntPart())
		case "duel_won":
			res.DuelWon = int32(stat.StatValue.IntPart())
		case "interception_won":
			res.Interception = int32(stat.StatValue.IntPart())
		case "accurate_pass":
			res.AccuratePass = int32(stat.StatValue.IntPart())
		case "successful_final_third_passes":
			res.AccurateFinalThirdPass = int32(stat.StatValue.IntPart())
		case "accurate_long_balls":
			res.AccurateLongBall = int32(stat.StatValue.IntPart())
		case "long_pass_own_to_opp_success":
			res.LongPassIntoOpposition = int32(stat.StatValue.IntPart())

		case "ontarget_scoring_att":
			res.ShotOnTarget = int32(stat.StatValue.IntPart())
		case "won_contest":
			res.WonContest = int32(stat.StatValue.IntPart())
		case "pen_area_entries":
			res.PenaltyAreaEntries = int32(stat.StatValue.IntPart())
		case "big_chance_created":
			res.BigChanceCreated = int32(stat.StatValue.IntPart())
		case "adjusted_total_att_assist":
			res.AttemptedAssist = int32(stat.StatValue.IntPart())
		case "penalty_kick_missed":
			res.PenaltyKickMissed = int32(stat.StatValue.IntPart())
		case "big_chance_missed":
			res.BigChanceMissed = int32(stat.StatValue.IntPart())
		}

		allAroundScore = allAroundScore.Add(stat.TotalScore)
	}
	res.MissedPass = int32(s.PlayerGameStats.TotalPass - s.PlayerGameStats.AccuratePass)
	if !tacklefound {
		res.WonTackle = int32(s.PlayerGameStats.TotalTackle)
	}

	for _, stat := range s.PositiveDecisiveStats {
		switch stat.Stat {
		case "goals":
			res.Goal = int32(stat.StatValue.IntPart())
		case "goal_assist":
			res.Assist = int32(stat.StatValue.IntPart())
		case "assist_penalty_won":
			res.PenaltyWon = int32(stat.StatValue.IntPart())
		case "clearance_off_line":
			res.ClearanceOffLine = int32(stat.StatValue.IntPart())
		case "last_man_tackle":
			res.LastManTackle = int32(stat.StatValue.IntPart())
		case "clean_sheet_60":
			res.CleanSheet = int32(stat.StatValue.IntPart()) == 1
		case "penalty_save":
			res.PenaltySave = int32(stat.StatValue.IntPart())
		}
	}

	for _, stat := range s.NegativeDecisiveStats {
		switch stat.Stat {
		case "red_card":
			res.RedCard = int(stat.StatValue.IntPart()) == 1
		case "own_goals":
			res.OwnGoal = int32(stat.StatValue.IntPart())
		case "error_lead_to_goal":
			res.ErrorLeadToGoal = int32(stat.StatValue.IntPart())
		case "penalty_conceded":
			res.PenaltyConceded = int32(stat.StatValue.IntPart())
		}
	}

	if s.PlayerGameStats.MinsPlayed == 0 {
		score = decimal.Zero
		decisiveScore = decimal.Zero
		allAroundScore = decimal.Zero
	}
	res.Score = score
	res.DecisiveScore = decisiveScore
	res.AllAroundScore = allAroundScore

	return res
}
